summaryrefslogtreecommitdiff
path: root/src/pipe_writer.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/pipe_writer.hpp')
-rw-r--r--src/pipe_writer.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/pipe_writer.hpp b/src/pipe_writer.hpp
index 2c5132e..a727b1f 100644
--- a/src/pipe_writer.hpp
+++ b/src/pipe_writer.hpp
@@ -28,10 +28,10 @@ namespace zmq
class pipe_writer_t : public object_t
{
// Dispatcher is a friend so that it can create & destroy the writer.
// By making constructor & destructor private we are sure that nobody
- // except dispatcher messes with writers.
- friend class dispatcher_t;
+ // except context messes with writers.
+ friend class context_t;
public:
@@ -28,10 +28,10 @@ namespace zmq
class pipe_writer_t : public object_t
{
- // Dispatcher is a friend so that it can create & destroy the writer.
+ // Context is a friend so that it can create & destroy the writer.
// By making constructor & destructor private we are sure that nobody